@@ -1,10 +1,10 @@
 import sys
 import click
 
-from .manager import manager
+from .startproject import startproject
 
 commands = [
-    manager
+    startproject
 ]
 
 
@@ -14,4 +14,7 @@ if __name__ == '__main__':
     args = sys.argv
     if "--help" in args or len(args) == 1:
         print("flaskmng")
-    main()
\ No newline at end of file
+    try:
+        main()
+    except Exception as e:
+        print("❌ "+str(e))
